﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.ChartView;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            var list = new List<DataItem>();
            Random r = new Random();
            for (int i = 0; i < 10; i++)
            {
                list.Add(new DataItem { Date = DateTime.Now.AddMonths(i), Value = r.Next(30, 300) });
            }

            var ChartMain = new RadCartesianChart();

            ChartMain.VerticalAxis = new LinearAxis();
            ChartMain.HorizontalAxis = new DateTimeContinuousAxis();
            ChartMain.Series.Add(new AreaSeries()
            {
                CategoryBinding = new PropertyNameDataPointBinding("Date"),
                ValueBinding = new PropertyNameDataPointBinding("Value"),
                ItemsSource = list,
                LegendSettings = new SeriesLegendSettings() { Title = "Series 1" }
            });

            Style style = new Style();
            style.TargetType = typeof(Line);
            style.Setters.Add(new Setter(Line.StrokeProperty, Brushes.Black));
            style.Setters.Add(new Setter(Line.StrokeThicknessProperty, 2.3));

            CartesianChartGrid chartGrid = new CartesianChartGrid();
            chartGrid.MajorLinesVisibility = GridLineVisibility.XY;
            chartGrid.MajorYLineStyle = style;
            chartGrid.MajorXLineStyle = style;

            ChartMain.Grid = chartGrid;

            //this.layoutGrid.Children.Add(ChartMain);

            StackPanel stackpanel = new StackPanel() { Orientation = Orientation.Vertical };

            ChartMain.Width = 1000;
            ChartMain.Height = 500;

            RadLegend legend = new RadLegend() { Items = ChartMain.LegendItems };
            legend.Width = 300;
            legend.Height = 500;

            stackpanel.Children.Add(ChartMain);
            stackpanel.Children.Add(legend);

            stackpanel.Width = ChartMain.Width;
            stackpanel.Height = ChartMain.Height + legend.Height;

            legend.Measure(new Size(legend.Width, legend.Height));
            legend.Arrange(new Rect(new Size(legend.Width, legend.Height)));

            ChartMain.Measure(new Size(ChartMain.Width, ChartMain.Height));
            ChartMain.Arrange(new Rect(new Size(ChartMain.Width, ChartMain.Height)));

            legend.UpdateLayout();
            ChartMain.UpdateLayout();
            stackpanel.UpdateLayout();

            stackpanel.Measure(new Size(stackpanel.Width, stackpanel.Height));
            stackpanel.Arrange(new Rect(new Size(stackpanel.Width, stackpanel.Height)));

            //string returnValue = ""

            //SaveToPng(stackpanel, returnValue);

            SaveFileDialog sfd = new SaveFileDialog();
            sfd.DefaultExt = "png";
            sfd.Filter = "PNG File (*.png) | *.png";
            if ((bool)sfd.ShowDialog())
            {
                using (var stream = sfd.OpenFile())
                {
                    Telerik.Windows.Media.Imaging.ExportExtensions.ExportToImage(stackpanel, stream, new PngBitmapEncoder());
                }
            }
        }
    }

    public class DataItem
    {
        public DateTime Date { get; set; }
        public Double Value { get; set; }
    }

}
